@@ -2,8 +2,8 @@
 try:
     __import__("pyblish_maya")
 
-except ImportError:
-    print "pyblish: Could not load integration"
+except ImportError as e:
+    print "pyblish: Could not load integration: %s" % e
 
 else:
     import pyblish_maya
